require 'spec_helper'
describe 'Satoshi API' do
	before(:all) do
		api_key = ENV['API_KEY']
		api_sign = ENV['API_SIGN']
    @satoshi = SatoshiRuby::Satoshi.new(api_key, api_sign)
	end

	it 'Satoshi keys should not be empty' do
		ENV['API_KEY'].should_not be_empty
		ENV['API_SIGN'].should_not be_empty
	end

	describe '-***Positive***-' do

		it 'Wallet address should return wallet addresses' do
			ret = @satoshi.wallet_address
	  	ret['status'].should eq 'success'
		end

		it 'Wallet address should return wallet address for BTC' do
			ret = @satoshi.wallet_address 'BTC'
	  	ret['status'].should eq 'success'
		end

		it 'Currency should return array of currencies' do
			ret = @satoshi.currency
	  	ret['status'].should eq 'success'
		end

		it 'Currency should return BTC currency' do
			ret = @satoshi.currency 'BTC'
	  	ret['status'].should eq 'success'
		end

		it 'Account should return main account' do
			ret = @satoshi.account
	  	ret['status'].should eq 'success'
		end

		it 'Balance should return balances list' do
			ret = @satoshi.balance
	  	ret['status'].should eq 'success'
		end

		it 'Balance should return BTC balance' do
			ret = @satoshi.balance 'BTC'
	  	ret['status'].should eq 'success'
		end

		it 'Ticker should return trading statistics' do
			ret = @satoshi.ticker 'btc', 'usd'
	  	ret['status'].should eq 'success'
		end

		it 'Quote should return trade cost' do
			ret = @satoshi.quote 'bid', 'btc', CurrencyUtility.currency_create_value(12, 1), 'usd', CurrencyUtility.currency_create_value_int(0.1, 4)
	  	ret['status'].should eq 'success'
	  	CurrencyUtility.currency_to_string(ret['data']['total']).should include('.')
		end

		it 'Orderbook should return orderbook' do
			ret = @satoshi.orderbook 'btc', 'usd', 1, 20
	  	ret['status'].should eq 'success'
		end

		it 'Orders should return my orders' do
			ret = @satoshi.orders 10, '1387972933374496'
	  	ret['status'].should eq 'success'
		end

		it 'Order details should return success' do
			ret = @satoshi.order_details 'nil'
	  	ret['status'].should eq 'success'
	  	ret['data'].should be_empty
		end


	end

	describe '-***Negative***-' do

		it 'Order details should return invalid signature' do
			ret = @satoshi.order_details nil
	  	ret['message'].should eq 'Invalid signature'
		end

		it 'Place should return invalid order currency' do
			ret = @satoshi.place 'bid', 'usd', CurrencyUtility.currency_create_value(12, 1), 'btc', CurrencyUtility.currency_create_value_int(0.1, 4)
	  	ret['message'].should eq 'Invalid order currency'
		end

		it 'Cancel should return invalid signature' do
			ret = @satoshi.cancel nil
	  	ret['message'].should eq 'Invalid signature'
		end

		it 'Cancel should return order_id must be a number' do
			ret = @satoshi.cancel 'nil'
	  	ret['status'].should eq 'error'
	  	ret['message'].should eq 'order_id must be a number'
		end

		it 'Cancel should return invalid order id' do
			ret = @satoshi.cancel 10000000000001
	  	ret['message'].should eq 'Invalid order_id'
		end

		it 'Wallet history should return error' do
			ret = @satoshi.wallet_history 'btc', nil
	  	ret['message'].should eq 'Invalid signature'
		end

	end

end